pub struct SessionCheckpointConfig {
pub pipeline: PipelineSettings,
pub permissions: GlobalPermissionSettings,
pub llm_primary_provider: String,
pub llm_fallback_provider: Option<String>,
pub openai_model: Option<String>,
pub anthropic_model: Option<String>,
pub grok_model: Option<String>,
pub ollama_model: Option<String>,
pub hooks: HooksSettings,
}Expand description
A redacted subset of configuration captured in a session checkpoint.
This intentionally excludes secrets such as API keys.
Fields
pipeline: PipelineSettingsPipeline behavior relevant to prompt/history management.
permissions: GlobalPermissionSettingsDefault permission behavior for new sessions.
llm_primary_provider: StringGlobal primary LLM provider id (e.g., “openai”, “anthropic”, “ollama”).
llm_fallback_provider: Option<String>Optional global fallback LLM provider id.
openai_model: Option<String>Optional global model selector for OpenAI (no secrets).
anthropic_model: Option<String>Optional global model selector for Anthropic (no secrets).
grok_model: Option<String>Optional global model selector for Grok (no secrets).
ollama_model: Option<String>Optional global model selector for Ollama (no secrets).
hooks: HooksSettingsHooks configuration (no secrets).
This is safe to capture because hook execution is still governed by explicit allow-listing of programs and hooks are disabled by default.
Implementations
Sourceimpl SessionCheckpointConfig
impl SessionCheckpointConfig
Sourcepub fn from_app_config(config: &AppConfig) -> Self
pub fn from_app_config(config: &AppConfig) -> Self
Build a checkpoint-safe config snapshot from the full application config.
This method must not include secrets (API keys).